@@ -1,22 +1,23 @@
 #' Simple theme for highcharts
+#'
+#' Theme smpl design is inspired by \url{https://github.com/hrbrmstr/hrbrmisc/blob/master/R/themes.r}
+#' and color by \url{https://www.materialui.co/flatuicolors}.
 #' 
-#' Design inspired by \url{https://github.com/hrbrmstr/hrbrmisc/blob/master/R/themes.r}
-#' and color by \url{https://www.materialui.co/flatuicolors}
+#' @param ... A named parameters to modify the theme.
 #' 
-#' @param ... Named argument to modify the theme
-#' 
-#' @examples 
-#' 
-#' highcharts_demo() %>% 
+#' @examples
+#'
+#' highcharts_demo() %>%
 #'   hc_add_theme(hc_theme_smpl())
-#' 
+#'   
 #' @export
-hc_theme_smpl <- function(...){
-  
+hc_theme_smpl <- function(...) {
   theme <-
     hc_theme(
-      colors = c("#d35400", "#2980b9", "#2ecc71",
-                 "#f1c40f", "#2c3e50", "#7f8c8d"),
+      colors = c(
+        "#d35400", "#2980b9", "#2ecc71",
+        "#f1c40f", "#2c3e50", "#7f8c8d"
+      ),
       chart = list(
         style = list(
           fontFamily = "Roboto",
@@ -78,14 +79,13 @@ hc_theme_smpl <- function(...){
     )
 
   theme <- structure(theme, class = "hc_theme")
-  
+
   if (length(list(...)) > 0) {
     theme <- hc_theme_merge(
       theme,
       hc_theme(...)
     )
-  } 
-  
+  }
+
   theme
-  
 }
